.. include:: ../README.rst


Contents:
---------

.. toctree::
   :maxdepth: 2

   self
   reference
   advanced
   goals
   development
   changelog



Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

